Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Skipped = fmt.Errorf("skipped")
Functions ¶
Types ¶
type DefaultDialect ¶
type DefaultDialect struct{}
DefaultDialect provides default behavior; most implementation specific dialects can be based on this one.
func (DefaultDialect) ColumnType ¶
func (_ DefaultDialect) ColumnType(typ string) string
func (DefaultDialect) ColumnTypeArg ¶
func (_ DefaultDialect) ColumnTypeArg(typ string, arg int) string
type Dialect ¶
type Dialect interface {
// DriverName is the name of the dialect; eg. postgres.
DriverName() string
// ColumnType maps a particular type into something that the implementation understands.
ColumnType(typ string) string
// ColumnTypeArg maps a particular type with an argument into something that the
// implementation understands.
ColumnTypeArg(typ string, arg int) string
}
Dialect specifies the behavior of a particular SQL implementation.
type QueryResult ¶
type Scanner ¶
type Scanner struct {
Filename string
// contains filtered or unexported fields
}
func NewScanner ¶
type TemplateContext ¶
type TemplateContext struct {
Global TestContext
Skip bool
// contains filtered or unexported fields
}
func NewTemplateContext ¶
func NewTemplateContext(dialect Dialect) *TemplateContext
func (*TemplateContext) Execute ¶
func (tmplCtx *TemplateContext) Execute(tmpl string) (string, TestContext, error)
Click to show internal directories.
Click to hide internal directories.